// $Id: editor_plugin_src.js,v 1.1.2.1 2009/12/02 22:26:06 meecect Exp $
/**
 * Copied from tinymce example plugin and modifed to suite its needs.
 *
 * http://27smiles.com
 * @author Richard Grundy
 *
 * modified 2009 Clifford Meece
 * http://cliffordmeece.com
 * added onBeforeSetContent and onPostProcess handlers
 * fixed onNodeChange (needs PRE, not IMG)
 */
 
(function() {
	//Load the language file.
	tinymce.PluginManager.requireLangPack('syntaxhl');
	
	tinymce.create('tinymce.plugins.SyntaxHL', {
		/**
		 * Initializes the plugin, this will be executed after the plugin has been created.
		 * This call is done before the editor instance has finished it's initialization so use the onInit event
		 * of the editor instance to intercept that event.
		 *
		 * @param {tinymce.Editor} ed Editor instance that the plugin is initialized in.
		 * @param {string} url Absolute URL to where the plugin is located.
		 */
		init : function(ed, url) {
			// Register the command so that it can be invoked by using tinyMCE.activeEditor.execCommand('mceExample');
			ed.addCommand('mceSyntaxHL', function() {
				ed.windowManager.open({
					file : url + '/dialog.htm',
					width : 450 + parseInt(ed.getLang('syntaxhl.delta_width', 0)),
					height : 400 + parseInt(ed.getLang('syntaxhl.delta_height', 0)),
					inline : 1
				}, {
					plugin_url : url // Plugin absolute URL
				});

			});
			ed.onBeforeSetContent.add(function(ed, o) {
			  o.content = o.content.replace(/{syntaxhighlighter ([^}]*)}/g,'<pre class="wysiwyg-syntaxhl $1">' );
			  o.content = o.content.replace(/{\/syntaxhighlighter}/g,'</pre><!-- /syntaxhl -->' );
			});
			ed.onPostProcess.add(function(ed, o) {
			  if (o.get){
			    o.content = o.content.replace(/<pre class="wysiwyg-syntaxhl ([^"]*)">/g,'{syntaxhighlighter $1}' );
			    o.content = o.content.replace(/<\/pre><!-- \/syntaxhl -->/g,'{/syntaxhighlighter}' );
        }
			});
			// Register example button
			ed.addButton('syntaxhl', {
				title : 'syntaxhl.desc',
				cmd : 'mceSyntaxHL',
				image : url + '/img/highlight.gif'
			});

			// Add a node change handler, selects the button in the UI when a <pre> element is selected
			ed.onNodeChange.add(function(ed, cm, n) {
				cm.setActive('syntaxhl', n.nodeName == 'PRE');
			});
		},

		/**
		 * Creates control instances based in the incomming name. This method is normally not
		 * needed since the addButton method of the tinymce.Editor class is a more easy way of adding buttons
		 * but you sometimes need to create more complex controls like listboxes, split buttons etc then this
		 * method can be used to create those.
		 *
		 * @param {String} n Name of the control to create.
		 * @param {tinymce.ControlManager} cm Control manager to use inorder to create new control.
		 * @return {tinymce.ui.Control} New control instance or null if no control was created.
		 */
		createControl : function(n, cm) {
			return null;
		},

		/**
		 * Returns information about the plugin as a name/value array.
		 * The current keys are longname, author, authorurl, infourl and version.
		 *
		 * @return {Object} Name/value array containing information about the plugin.
		 */
		getInfo : function() {
			return {
				longname : 'Syntax Highlighter',
				author : 'Richard Grundy',
				authorurl : 'http://27smiles.com',
				infourl : 'http://27smiles.com',
				version : "1.0"
			};
		}
	});

	// Register plugin
	tinymce.PluginManager.add('syntaxhl', tinymce.plugins.SyntaxHL);
})();